@@ -8,22 +8,33 @@ if (!checkSqlite())   exit_file("Reason: no SQLite")
 if (!checkInternet()) exit_file("Reason: no internet connectivity")
 if (!checkBinaries()) exit_file("Reason: no binaries php or sed or perl")
 
-# create database object
-dbc <- nodbi::src_sqlite(
-  dbname = ":memory:",
-  collection = mongoLocalRwCollection)
-
 #### CTGOV ####
 tf <- function() {
+
+  # create database object
+  dbc <- suppressWarnings(nodbi::src_sqlite(
+    dbname = ":memory:",
+    collection = mongoLocalRwCollection))
+
   # register clean-up
   on.exit(expr = {
     try({
-      RSQLite::dbRemoveTable(conn = dbc$con, name = dbc$collection)
+      if (DBI::dbExistsTable(conn = dbc$con, name = dbc$collection))
+        DBI::dbRemoveTable(conn = dbc$con, name = dbc$collection)
       RSQLite::dbDisconnect(conn = dbc$con)
+      rm(dbc)
     },
     silent = TRUE)
-  })
+  }, add = TRUE)
+
+  # check server
+  if (httr::status_code(
+    httr::HEAD("https://clinicaltrials.gov/ct2/search",
+               httr::timeout(10L))) != 200L
+  ) return(exit_file("Reason: CTGOV not working"))
+
   # do tests
   source("ctrdata_ctgov.R", local = TRUE)
+
 }
 tf()
